# chitChat Client Package

Welcome to chitChat, a python chat server package!

To run a chitChat client, enter into the python REPL:

`python`

To run a client from the REPL:

`from client_pkg import client`

`client.main()`